# Getting Started

Most of ggcmpy is actually invisible to the user -- it provides backends to the
[Xarray](https://xarray.dev) library that "makes working with labelled
multi-dimensional arrays in Python simple, efficient, and fun!"

```{toctree}
:maxdepth: 2
:hidden:

installing
quick-overview
solarwind
faq
```
